(document:surround "/std/frame")

(define *name* (global 'name))

;;; UI

width 600
height 500

(hbox align "left"
      (label text (bold (_ "Bonded interface ")))(label name "iface_label")
      (label name "iface" visibility #t))
(button (_ "Back") name "back")
(separator)
(gridbox columns "45;10;45"
	  (label text (_ "Members"))
	  (spacer)
      (label text (_ "Available interfaces"))
  (listbox name "bonded_ifaces")
  (gridbox columns "100"
	(spacer)
	(button text (_ "<<") (when clicked (add-iface)))
	(button text (_ ">>") (when clicked (del-iface)))
	(spacer))
  (listbox name "avail_ifaces")
)

(gridbox
    columns "0;100"
    (radio name "mode" align "left" value "0" text (_ "Round-robin"))
    (spacer)
    (radio name "mode" align "left" value "1" text (_ "Active-backup"))
    (spacer)
    (radio name "mode" align "left" value "2" text (_ "XOR"))
    (spacer)
    (radio name "mode" align "left" value "3" text (_ "Broadcast"))
    (spacer)
    (radio name "mode" align "left" value "4" text (_ "IEEE 802.3ad Dynamic link aggregation"))
    (spacer)
    (radio name "mode" align "left" value "5" text (_ "Adaptive transmit load balancing"))
    (spacer)
    (radio name "mode" align "left" value "6" text (_ "Adaptive load balancing"))
    (spacer)
	(hbox align "left"
       (label text (_ "Bond options:"))
          (edit name "bond_options")
          (spacer))
)

;;; Functions

(define (ui-update-lists bond)
  (catch/message
	(lambda()
	  (form-update-enum "bonded_ifaces" (woo-list "/net-bond/bonded_ifaces" 'bond bond))
	  (form-update-enum "avail_ifaces" (woo-list "/net-bond/avail_ifaces")))))

(define (init-bond-name fname)
  (if (or (not fname)
		  (empty-string? fname))
	(woo-get-option (woo-read-first "/net-bond/new_name") 'new_name)
	fname))

(define (ui-read bond)
  (form-update-value "iface" bond)
  (catch/message
	(lambda()
	  (let ((cmd (woo-read-first "/net-bond" 'bond bond)))
		(ui-update-lists bond)
		(form-update-value-list '("mode" "bond_options") cmd)))))

(define (add-iface)
  (let* ((bond (form-value "iface"))
		(name (or (form-value "avail_ifaces") "")))
	(catch/message
	  (lambda()
		(woo-write "/net-bond/add_iface" 'language (form-value "language") 'bond bond 'name name)))
	(ui-update-lists bond)))


(define (del-iface)
  (let ((bond (form-value "iface"))
		(name (or (form-value "bonded_ifaces") "")))
	(catch/message
	  (lambda()
		(woo-write "/net-bond/del_iface" 'language (form-value "language") 'bond bond 'name name)))
	(ui-update-lists bond)))

(define (ui-write)
   (catch/message
	 (lambda()
	   (woo-write "/net-bond" 'language (form-value "language")
				  'bond (form-value "iface")
				  'bond_options (form-value "bond_options")
				  'mode (form-value "mode")))))

(define (ui-init name)
  (ui-read (init-bond-name name)))

(define (ui-exit)
  (ui-write)
  (document:end))

;;
(document:root
  (when loaded
  (ui-init *name*)
  (form-bind "back" "click" ui-exit)))
